# CoreX security - ldap

This package provides an implementation of the CoreX security interface for ldap.

## Installation
~~~bash
pip install corex-security-ldap
~~~

## Usage
~~~python
from corex_security_ldap.handler import LdapHandler
handler = LdapHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
